@@ -1,5 +1,20 @@
 use super::*;
+use std::marker::PhantomData;
 mod convert;
+mod regular;
+
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
+pub struct RegularPolygon<T> {
+    pub sides: usize,
+    pub center: Point<T>,
+    pub radius: T,
+    pub rotate: T,
+}
+
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
+pub struct CirclePoints<T> {
+    ty: PhantomData<T>,
+}
 
 #[derive(Debug, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
 pub struct Polyline<T> {
