@@ -1,5 +1,3 @@
-use crate::{Area, Point};
-mod area;
 mod valid;
 use crate::{Rectangle, Square, Triangle, ValidShape, Vector};
 use num_traits::{Num, Zero};
