@@ -2,10 +2,12 @@ use super::*;
 
 impl<T> ValidShape<T> for Triangle<T>
 where
-    T: Zero,
+    T: Num + PartialOrd + Clone,
 {
     fn is_empty_under_thousand(&self, thousand: T) -> bool {
-        todo!()
+        let a = Vector::from_2_points(self.vertex[0].clone(), self.vertex[1].clone());
+        let b = Vector::from_2_points(self.vertex[1].clone(), self.vertex[2].clone());
+        a.dx * b.dy - a.dy * b.dx < thousand
     }
 }
 
