@@ -25,7 +25,3 @@ where
 pub trait EqualThousand<T> {
     fn eq_under_thousand(&self, thousand: T) -> bool;
 }
-
-pub trait Area<T> {
-    fn area(&self) -> T;
-}
